#
# spec file for package python-pyeapi
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyeapi
Version:        1.0.2
Release:        2.3
Summary:        Python Client for eAPI
License:        BSD-3-Clause
URL:            https://github.com/arista-eosplus/pyeapi
Source:         https://files.pythonhosted.org/packages/source/p/pyeapi/pyeapi-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#arista-eosplus/pyeapi#292
Patch0:         no-more-imp.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module netaddr}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-netaddr
BuildArch:      noarch
%python_subpackages

%description
The Python Client for eAPI (pyeapi) is a native Python library wrapper around
Arista EOS eAPI.  It provides a set of Python language bindings for configuring
Arista EOS nodes.

The Python library can be used to communicate with EOS either locally
(on-box) or remotely (off-box). It uses a standard INI-style configuration file
to specify one or more nodes and connection profiles.

The pyeapi library also provides an API layer for building native Python
objects to interact with the destination nodes. The API layer is a convenient
implementation for working with the EOS configuration and is extensible for
developing custom implementations.

%prep
%autosetup -p1 -n pyeapi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}

%check
%pytest test/unit

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%doc examples
%{python_sitelib}/pyeapi
%{python_sitelib}/pyeapi-%{version}.dist-info

%changelog
* Mon Feb 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup macro.
- Add patch no-more-imp.patch:
  * Use importlib, rather than imp.
* Mon Jan  1 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Fixed all system tests and provides some enhancements for
    unit tests
- update to 1.0.1:
  * This is an interim release for EOS integration purpose
- update to 1.0.0:
  * This is a Python3 only release (Python2 is no longer
    supported)
  * The minimum supported python version is 3.7
  * Arista EOS 4.22 or later is required (for on-box use cases
    only)
* Wed Apr  6 2022 pgajdos@suse.com
- do not require python-mock for build
* Tue Jan 11 2022 Ben Greiner <code@bnavigator.de>
- Fix deprecated collections.abc imports still not fully fixed in
  0.8.4 -- gh#arista-eosplus/pyeapi#195
- Use the PyPI archive, because the git source has the wrong
  version in its metadata
* Sat Nov 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.4
  * Fix deprecated 'collections' dependancy
  * Power support(ppc64le) with continuous integration
* Sun Jan 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.3
  * This release includes checks on ACL regexp statement of
    'match', adopts changes of CLI described in Field Notice 0039
- Use github source URL
* Sun Sep 29 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.2
- Specfile cleanup
* Mon Aug  7 2017 mardnh@gmx.de
- Update to version 0.8.1
- Convert to singlespec
* Wed Aug 31 2016 mardnh@gmx.de
- initial package, version 0.6.1
